@@ -7,7 +7,7 @@ use Carp 'croak';
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 #------------------------------------------------------------------------------
@@ -193,7 +193,7 @@ use DateTime;
 use DateTime::TimeZone;
 use Carp qw{carp croak};
 use Clone;
-use base 'Tie::StdHash';
+use base 'Tie::Hash';
 
 # debugging tools
 # use Debug::ShowStuff ':all';
@@ -1891,6 +1891,10 @@ Initial release.
 
 Added support for default time zone.
 
+=item Version 0.03 Aug 6, 2016
+
+Modified to use Tie::Hash.
+
 =back
 
 =cut
